import type { Either, ErrorResolver } from '@lokalise/node-core';
import type { QueueConsumer, NewQueueOptions, ExistingQueueOptions, Prehandler } from '@message-queue-toolkit/core';
import type { Connection, Message } from 'amqplib';
import type { AMQPConsumerDependencies, CreateAMQPQueueOptions } from './AbstractAmqpService';
import { AbstractAmqpService } from './AbstractAmqpService';
export type AMQPLocatorType = {
    queueName: string;
};
export type CommonQueueOptions<MessagePayloadType extends object, ExecutionContext, PrehandlerOutput> = {
    prehandlers?: Prehandler<MessagePayloadType, ExecutionContext, PrehandlerOutput>[];
};
export type NewAMQPConsumerOptions<MessagePayloadType extends object, ExecutionContext = undefined, PrehandlerOutput = undefined> = NewQueueOptions<CreateAMQPQueueOptions> & CommonQueueOptions<MessagePayloadType, ExecutionContext, PrehandlerOutput>;
export type ExistingAMQPConsumerOptions<MessagePayloadType extends object, ExecutionContext = undefined, PrehandlerOutput = undefined> = ExistingQueueOptions<AMQPLocatorType> & CommonQueueOptions<MessagePayloadType, ExecutionContext, PrehandlerOutput>;
export declare abstract class AbstractAmqpBaseConsumer<MessagePayloadType extends object, ExecutionContext, PrehandlerOutput, BarrierOutput> extends AbstractAmqpService<MessagePayloadType, AMQPConsumerDependencies, ExecutionContext, PrehandlerOutput, BarrierOutput> implements QueueConsumer {
    private readonly transactionObservabilityManager?;
    protected readonly errorResolver: ErrorResolver;
    constructor(dependencies: AMQPConsumerDependencies, options: NewAMQPConsumerOptions<MessagePayloadType, ExecutionContext, PrehandlerOutput> | ExistingAMQPConsumerOptions<MessagePayloadType, ExecutionContext, PrehandlerOutput>);
    private internalProcessMessage;
    private deserializeMessage;
    receiveNewConnection(connection: Connection): Promise<void>;
    private tryToExtractId;
    private consume;
    start(): Promise<void>;
    protected resolveMessage(message: Message): Either<import("@message-queue-toolkit/core").MessageInvalidFormatError | import("@message-queue-toolkit/core").MessageValidationError, unknown>;
}
